#include "FL/Fl.H"
#include "FL/Fl_Window.H"
#include "FL/Fl_Box.H"
#include "FL/fl_draw.H"

// Rosé Pine-inspired color scheme
Fl_Color backgroundColor = fl_rgb_color(25, 23, 36);      // #191724
Fl_Color textColor = fl_rgb_color(224, 222, 244);         // #e0def4
Fl_Color accentColor = fl_rgb_color(196, 167, 231);       // #c4a7e7
Fl_Color secondaryAccent = fl_rgb_color(235, 188, 186);   // #ebbcba
Fl_Color boxColor = fl_rgb_color(48, 44, 64);             // Slightly darker than the background
Fl_Color highlightColor = fl_rgb_color(143, 131, 174);    // Softer purple for hover effect

// Custom Box with Rosé Pine-inspired style
class StyledBox : public Fl_Box {
public:
    Fl_Color current_color;

    StyledBox(int x, int y, int w, int h, const char *label = 0)
            : Fl_Box(x, y, w, h, label), current_color(boxColor) {
        box(FL_FLAT_BOX);
    }

    void draw() override {
        // background color
        fl_color(current_color);
        fl_rectf(x(), y(), w(), h(), current_color);

        // border
        fl_color(accentColor);
        fl_rect(x() + 5, y() + 5, w() - 10, h() - 10, accentColor);

        // label with custom font and color
        fl_color(textColor);
        fl_font(FL_HELVETICA_BOLD, 20);  // Minimalist font size and style
        fl_draw(label(), x(), y(), w(), h(), FL_ALIGN_CENTER);
    }

    // Mouse hover event
    int handle(int event) override {
        switch (event) {
            case FL_ENTER:
                current_color = highlightColor;
                redraw();
                return 1;
            case FL_LEAVE:
                current_color = boxColor;
                redraw();
                return 1;
            default:
                return Fl_Box::handle(event);
        }
    }
};

int main(int argc, char **argv) {
    Fl_Window *window = new Fl_Window(400, 300, "Rosé Pine Styled FLTK");
    window->color(backgroundColor);
    StyledBox *box = new StyledBox(50, 100, 300, 80, "Hello, Rosé Pine!");

    window->end();
    window->show(argc, argv);

    return Fl::run();
}
